@@ -84,7 +84,7 @@ def _do_query(lib, query, album, also_items=True):
 
 def _print_keys(query):
     """Given a SQLite query result, print the `key` field of each
-    returned row, with identation of 2 spaces.
+    returned row, with indentation of 2 spaces.
     """
     for row in query:
         print_(u' ' * 2 + row['key'])
@@ -613,6 +613,9 @@ def choose_candidate(candidates, singleton, rec, cur_artist=None,
         })
         if default is None:
             require = True
+        # Bell ring when user interaction is needed.
+        if config['import']['bell']:
+            ui.print_(u'\a', end=u'')
         sel = ui.input_options((u'Apply', u'More candidates') + choice_opts,
                                require=require, default=default)
         if sel == u'a':
@@ -941,6 +944,10 @@ import_cmd.parser.add_option(
     u'-C', u'--nocopy', action='store_false', dest='copy',
     help=u"don't copy tracks (opposite of -c)"
 )
+import_cmd.parser.add_option(
+    u'-m', u'--move', action='store_true', dest='move',
+    help=u"move tracks into the library (overrides -c)"
+)
 import_cmd.parser.add_option(
     u'-w', u'--write', action='store_true', default=None,
     help=u"write new metadata to files' tags (default)"
