@@ -21,6 +21,7 @@ from __future__ import absolute_import, division, print_function
 import difflib
 import itertools
 import json
+import struct
 import re
 import requests
 import unicodedata
@@ -53,7 +54,6 @@ from beets import plugins
 from beets import ui
 import beets
 
-
 DIV_RE = re.compile(r'<(/?)div>?', re.I)
 COMMENT_RE = re.compile(r'<!--.*-->', re.S)
 TAG_RE = re.compile(r'<[^>]*>')
@@ -77,6 +77,12 @@ USER_AGENT = 'beets/{}'.format(beets.__version__)
 
 # Utilities.
 
+def unichar(i):
+    try:
+        return six.unichr(i)
+    except ValueError:
+        return struct.pack('i', i).decode('utf-32')
+
 
 def unescape(text):
     """Resolve &#xxx; HTML entities (and some others)."""
@@ -86,7 +92,7 @@ def unescape(text):
 
     def replchar(m):
         num = m.group(1)
-        return six.unichr(int(num))
+        return unichar(int(num))
     out = re.sub(u"&#(\d+);", replchar, out)
     return out
 
@@ -104,7 +110,6 @@ def extract_text_in(html, starttag):
     """Extract the text from a <DIV> tag in the HTML starting with
     ``starttag``. Returns None if parsing fails.
     """
-
     # Strip off the leading text before opening tag.
     try:
         _, html = html.split(starttag, 1)
@@ -145,10 +150,10 @@ def search_pairs(item):
     and featured artists from the strings and add them as candidates.
     The method also tries to split multiple titles separated with `/`.
     """
-
     def generate_alternatives(string, patterns):
         """Generate string alternatives by extracting first matching group for
-           each given pattern."""
+           each given pattern.
+        """
         alternatives = [string]
         for pattern in patterns:
             match = re.search(pattern, string, re.IGNORECASE)
@@ -254,16 +259,18 @@ class MusiXmatch(SymbolsReplaced):
 
     def fetch(self, artist, title):
         url = self.build_url(artist, title)
+
         html = self.fetch_url(url)
         if not html:
             return
-        lyrics = extract_text_between(html,
-                                      '"body":', '"language":')
+        html_part = html.split('<p class="mxm-lyrics__content')[-1]
+        lyrics = extract_text_between(html_part, '>', '</p>')
         return lyrics.strip(',"').replace('\\n', '\n')
 
 
 class Genius(Backend):
     """Fetch lyrics from Genius via genius-api."""
+
     def __init__(self, config, log):
         super(Genius, self).__init__(config, log)
         self.api_key = config['genius_api_key'].as_str()
@@ -355,6 +362,7 @@ class Genius(Backend):
 
 class LyricsWiki(SymbolsReplaced):
     """Fetch lyrics from LyricsWiki."""
+
     URL_PATTERN = 'http://lyrics.wikia.com/%s:%s'
 
     def fetch(self, artist, title):
@@ -373,38 +381,6 @@ class LyricsWiki(SymbolsReplaced):
                 return lyrics
 
 
-class LyricsCom(Backend):
-    """Fetch lyrics from Lyrics.com."""
-    URL_PATTERN = 'http://www.lyrics.com/%s-lyrics-%s.html'
-    NOT_FOUND = (
-        'Sorry, we do not have the lyric',
-        'Submit Lyrics',
-    )
-
-    @classmethod
-    def _encode(cls, s):
-        s = re.sub(r'[^\w\s-]', '', s)
-        s = re.sub(r'\s+', '-', s)
-        return super(LyricsCom, cls)._encode(s).lower()
-
-    def fetch(self, artist, title):
-        url = self.build_url(artist, title)
-        html = self.fetch_url(url)
-        if not html:
-            return
-        lyrics = extract_text_between(html, '<div id="lyrics" class="SCREENO'
-                                      'NLY" itemprop="description">', '</div>')
-        if not lyrics:
-            return
-        for not_found_str in self.NOT_FOUND:
-            if not_found_str in lyrics:
-                return
-
-        parts = lyrics.split('\n---\nLyrics powered by', 1)
-        if parts:
-            return parts[0]
-
-
 def remove_credits(text):
     """Remove first/last line of text if it contains the word 'lyrics'
     eg 'Lyrics by songsdatabase.com'
@@ -478,6 +454,7 @@ def scrape_lyrics_from_html(html):
 
 class Google(Backend):
     """Fetch lyrics from Google search results."""
+
     def __init__(self, config, log):
         super(Google, self).__init__(config, log)
         self.api_key = config['google_API_key'].as_str()
@@ -563,12 +540,18 @@ class Google(Backend):
               % (self.api_key, self.engine_id,
                  urllib.parse.quote(query.encode('utf-8')))
 
-        data = urllib.request.urlopen(url)
-        data = json.load(data)
+        data = self.fetch_url(url)
+        if not data:
+            self._log.debug(u'google backend returned no data')
+            return None
+        try:
+            data = json.loads(data)
+        except ValueError as exc:
+            self._log.debug(u'google backend returned malformed JSON: {}', exc)
         if 'error' in data:
             reason = data['error']['errors'][0]['reason']
-            self._log.debug(u'google lyrics backend error: {0}', reason)
-            return
+            self._log.debug(u'google backend error: {0}', reason)
+            return None
 
         if 'items' in data.keys():
             for item in data['items']:
@@ -589,11 +572,10 @@ class Google(Backend):
 
 
 class LyricsPlugin(plugins.BeetsPlugin):
-    SOURCES = ['google', 'lyricwiki', 'lyrics.com', 'musixmatch']
+    SOURCES = ['google', 'lyricwiki', 'musixmatch']
     SOURCE_BACKENDS = {
         'google': Google,
         'lyricwiki': LyricsWiki,
-        'lyrics.com': LyricsCom,
         'musixmatch': MusiXmatch,
         'genius': Genius,
     }
@@ -707,7 +689,8 @@ class LyricsPlugin(plugins.BeetsPlugin):
 
     def fetch_item_lyrics(self, lib, item, write, force):
         """Fetch and store lyrics for a single item. If ``write``, then the
-        lyrics will also be written to the file itself."""
+           lyrics will also be written to the file itself.
+        """
         # Skip if the item already has lyrics.
         if not force and item.lyrics:
             self._log.info(u'lyrics already present: {0}', item)
